--- postfix-1.1.11/src/global/mail_params.h	Wed May 29 04:07:30 2002
+++ postfix-1.1.11.patched/src/global/mail_params.h	Fri May 16 16:14:39 2003
@@ -1141,6 +1141,7 @@
 #define DEF_NON_FQDN_CODE	504	/* POLICY */
 extern int var_non_fqdn_code;
 
+#define REJECT_UNKNOWN_LOCAL_SENDER "reject_unknown_local_sender"
 #define REJECT_UNKNOWN_SENDDOM	"reject_unknown_sender_domain"
 #define REJECT_UNKNOWN_RCPTDOM	"reject_unknown_recipient_domain"
 #define REJECT_UNKNOWN_ADDRESS	"reject_unknown_address"
--- postfix-1.1.11/src/smtpd/smtpd_check.c	Wed May 15 05:13:03 2002
+++ postfix-1.1.11.patched/src/smtpd/smtpd_check.c	Fri May 16 17:05:28 2003
@@ -1394,6 +1394,44 @@
     return (stat);
 }
 
+/* reject_unknown_local_sender - fail if sender doamin is local, but user not exists */
+
+static int reject_unknown_local_sender(SMTPD_STATE *state, const char *addr,
+		            const char *reply_name, const char *reply_class)
+{
+    char   *myname = "reject_unknown_local_sender";
+    const RESOLVE_REPLY *reply;
+    const char *domain;
+
+    if (msg_verbose)
+	msg_info("%s: addr is %s", myname, addr);
+
+    /*
+     * Resolve the address.
+     */
+    reply = (const RESOLVE_REPLY *) ctable_locate(smtpd_resolve_cache, addr);
+
+    /*
+     * Skip local destinations and non-DNS forms.
+     */
+    if ((domain = strrchr(CONST_STR(reply->recipient), '@')) == 0)
+	return (SMTPD_CHECK_DUNNO);
+    domain += 1;
+    if (resolve_local(domain)) {
+        if (*var_local_rcpt_maps &&
+               (check_mail_addr_find(state, addr, 
+                                     local_rcpt_maps, 
+                                     CONST_STR(reply->recipient), 
+                                     (char **)0) == 0)) {
+             return (smtpd_check_reject(state, MAIL_ERROR_POLICY,
+                                  "%d <%s>: %s rejected: local user not exist",
+                                     450,
+                                     reply_name, reply_class));
+        }
+    }
+    return (SMTPD_CHECK_DUNNO);
+}
+
 /* reject_unknown_address - fail if address does not resolve */
 
 static int reject_unknown_address(SMTPD_STATE *state, const char *addr,
@@ -2120,6 +2158,10 @@
 	} else if (strcasecmp(name, REJECT_UNKNOWN_ADDRESS) == 0) {
 	    if (state->sender && *state->sender)
 		status = reject_unknown_address(state, state->sender,
+					  state->sender, SMTPD_NAME_SENDER);
+	} else if (strcasecmp(name, REJECT_UNKNOWN_LOCAL_SENDER) == 0) {
+	    if (state->sender && *state->sender)
+		status = reject_unknown_local_sender(state, state->sender,
 					  state->sender, SMTPD_NAME_SENDER);
 	} else if (strcasecmp(name, REJECT_UNKNOWN_SENDDOM) == 0) {
 	    if (state->sender && *state->sender)
